# Saphyr

<img width=100 src="https://raw.githubusercontent.com/laibulle/saphir/master/docs/files/logo.svg">

Fullstack and scalable python web framework based on uvloop.

Is it ready for prod ? __Nooooooooooo__

__Goals__

- Strongly opinionated
- Fast prototyping
- Async IO
- First class interop with Rust

__Inspirations__

- Phoenix
- NodeJs

__todo__

- controllers
- service container
- controller test samples


__Getting started__

```
saphyr new my_project
```